#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
#
from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    TextAscii,
    Tuple,
    ListOf,
    TextUnicode,
    MonitoringState,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_checkpoint_l2l_vpn():
    return Dictionary(
        elements=[
            ('not_found_state',
             MonitoringState(
                 title=_('Default state to report when tunnel can not be found anymore'),
                 help=_('Default state if a tunnel, which is not listed above in this rule, '
                        'can no longer be found.'),
                 default_value=3,
             )),
            ('tunnels',
             ListOf(
                 Tuple(
                     title=_('VPN Tunnel Endpoints'),
                     elements=[
                         TextUnicode(
                             title=_('Peer object name'),
                             help=_('The configured value must match a tunnel reported by the monitored '
                                    'device.'),
                             allow_empty=False,
                         ),
                         TextUnicode(
                             title=_('Tunnel Alias'),
                             help=_('You can configure an individual alias here for the tunnel matching '
                                    'the Name configured in the field above.'),
                         ),
                         MonitoringState(
                             default_value=2,
                             title=_('State if tunnel is not found'),
                         )]),
                 add_label=_('Add tunnel'),
                 movable=False,
                 title=_('VPN tunnel specific configuration'),
             )),
            ('vpn_entry',  # added by plugin discovery function
             Dictionary(
                 elements=[
                     ('l2lcommunity', TextUnicode()),
                     ('l2lpeeripaddr', TextUnicode())
                 ]
             )),
        ],
        hidden_keys=['vpn_entry'],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='checkpoint_l2l_vpn',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_l2l_vpn,
        title=lambda: _('Check Point L2L VPN'),
        item_spec=lambda: TextAscii(title=_('Peer object name'), ),
    ))
